UnitExponents

Struct UnitExponents 

#[repr(C)]
pub struct UnitExponents { pub second: i32, pub meter: i32, pub kilogram: i32, pub ampere: i32, pub kelvin: i32, pub mol: i32, pub candela: i32, }
Struct representing a unit of measurement in the SI system via the exponents of the base units.

Fields

second: i32

Exponent for the SI base unit of time.

meter: i32

Exponent for the SI base unit of length.

kilogram: i32

Exponent for the SI base unit of mass.

ampere: i32

Exponent for the SI base unit of electrical current.

kelvin: i32

Exponent for the SI base unit of temperature.

mol: i32

Exponent for the SI base unit of amount of substance.

candela: i32

Exponent for the SI base unit of luminous intensity

Implementations

Source

impl UnitExponents

pub const fn time() -> Self

Returns the UnitExponents for time.

pub const fn length() -> Self

Returns the UnitExponents for length.

pub const fn mass() -> Self

Returns the UnitExponents for mass.

pub const fn electric_current() -> Self

Returns the UnitExponents for (electric) current.

pub const fn temperature() -> Self

Returns the UnitExponents for temperature.

pub const fn amount_of_substance() -> Self

Returns the UnitExponents for amount of substance.

pub const fn luminous_intensity() -> Self

Returns the UnitExponents for luminous intensity.

pub const fn area() -> Self

Returns the UnitExponents for surface area.

pub const fn volume() -> Self

Returns the UnitExponents for volume.

pub const fn electric_voltage() -> Self

Returns the UnitExponents for (electric) voltage.

pub const fn force() -> Self

Returns the UnitExponents for force.

pub const fn torque() -> Self

Returns the UnitExponents for torque.

pub const fn power() -> Self

Returns the UnitExponents for power.

pub const fn energy() -> Self

Returns the UnitExponents for energy.

pub const fn frequency() -> Self

Returns the UnitExponents for frequency.

pub const fn velocity() -> Self

Returns the UnitExponents for (linear) velocity.

pub const fn angular_velocity() -> Self

Returns the UnitExponents for (angular) velocity.

pub const fn magnetic_flux() -> Self

Returns the UnitExponents for magnetic flux.

pub const fn magnetic_flux_density() -> Self

Returns the UnitExponents for magnetic flux density.

pub const fn magnetic_field_strength() -> Self

Returns the UnitExponents for magnetic field strength.

pub const fn inductance() -> Self

Returns the UnitExponents for inductance.

pub const fn electric_conductance() -> Self

Returns the UnitExponents for (electric) conductance.

pub const fn electric_resistance() -> Self

Returns the UnitExponents for (electric) resistance.

pub const fn electric_conductivity() -> Self

Returns the UnitExponents for (electric) conductivity.

pub const fn electric_resistivity() -> Self

Returns the UnitExponents for (electric) resistivity.

Source

impl UnitExponents

pub fn powi(self, n: i32) -> Self

Raises self to an integer power.

Examples
use dyn_quantity::UnitExponents;

let exponents = UnitExponents::from([0, 1, 0, 2, 0, -2, 0]);
let array: [i32; 7] = exponents.powi(2).into();
assert_eq!(array, [0, 2, 0, 4, 0, -4, 0]);
pub fn try_nthroot(self, n: i32) -> Result<Self, RootError>

Tries to calculate the nth root of self. This operation fails if any of the exponents is not divisible by n.

Examples
use dyn_quantity::UnitExponents;

let exponents = UnitExponents::from([0, 2, 0, 2, 0, -4, 0]);

// It is possible to calculate the square root:
let array: [i32; 7] = exponents.clone().try_nthroot(2).unwrap().into();
assert_eq!(array, [0, 1, 0, 1, 0, -2, 0]);

// But not the cubic root (not all exponents are divisible by 3):
assert!(exponents.try_nthroot(3).is_err());