#[repr(C)]pub struct UnitExponents {
pub second: i32,
pub meter: i32,
pub kilogram: i32,
pub ampere: i32,
pub kelvin: i32,
pub mol: i32,
pub candela: i32,
}Expand description
Struct representing a unit of measurement in the SI system via the exponents of the base units.
Fields
second: i32meter: i32kilogram: i32ampere: i32kelvin: i32mol: i32candela: i32Implementations
Sourceimpl UnitExponents
impl UnitExponents
Sourcepub fn powi(self, n: i32) -> Self
pub fn powi(self, n: i32) -> Self
Raises self to an integer power.
Examples
use dyn_quantity::UnitExponents;
let exponents = UnitExponents::from([0, 1, 0, 2, 0, -2, 0]);
let array: [i32; 7] = exponents.powi(2).into();
assert_eq!(array, [0, 2, 0, 4, 0, -4, 0]);Sourcepub fn try_nthroot(self, n: i32) -> Result<Self, RootError>
pub fn try_nthroot(self, n: i32) -> Result<Self, RootError>
Tries to calculate the nth root of self. This operation fails if any
of the exponents is not divisible by n.
Examples
use dyn_quantity::UnitExponents;
let exponents = UnitExponents::from([0, 2, 0, 2, 0, -4, 0]);
// It is possible to calculate the square root:
let array: [i32; 7] = exponents.clone().try_nthroot(2).unwrap().into();
assert_eq!(array, [0, 1, 0, 1, 0, -2, 0]);
// But not the cubic root (not all exponents are divisible by 3):
assert!(exponents.try_nthroot(3).is_err());Trait Implementations
Sourceimpl Clone for UnitExponents
impl Clone for UnitExponents
Sourcefn clone(&self) -> UnitExponents
fn clone(&self) -> UnitExponents
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnitExponents
impl Debug for UnitExponents
Sourceimpl Default for UnitExponents
impl Default for UnitExponents
Sourcefn default() -> UnitExponents
fn default() -> UnitExponents
Returns the “default value” for a type. Read more
Sourceimpl Display for UnitExponents
impl Display for UnitExponents
Sourceimpl Div for UnitExponents
impl Div for UnitExponents
Sourceimpl DivAssign for UnitExponents
impl DivAssign for UnitExponents
Sourcefn div_assign(&mut self, rhs: Self)
fn div_assign(&mut self, rhs: Self)
Performs the
/= operation. Read moreSourceimpl From<[i32; 7]> for UnitExponents
impl From<[i32; 7]> for UnitExponents
Sourcefn from(array: [i32; 7]) -> Self
fn from(array: [i32; 7]) -> Self
Converts an array of seven i32 values into UnitExponents.
The individual array elements are interpreted as follows:
array[0]: Exponent of secondarray[1]: Exponent of meterarray[2]: Exponent of kilogramarray[3]: Exponent of amperearray[4]: Exponent of kelvinarray[5]: Exponent of molarray[6]: Exponent of candela
Sourceimpl From<UnitExponents> for [i32; 7]
impl From<UnitExponents> for [i32; 7]
Sourcefn from(value: UnitExponents) -> Self
fn from(value: UnitExponents) -> Self
Converts an UnitExponents into an array of seven i32.
The exponents are put into the array in the following order:
array[0]: Exponent of secondarray[1]: Exponent of meterarray[2]: Exponent of kilogramarray[3]: Exponent of amperearray[4]: Exponent of kelvinarray[5]: Exponent of molarray[6]: Exponent of candela
Sourceimpl Mul for UnitExponents
impl Mul for UnitExponents
Sourceimpl MulAssign for UnitExponents
impl MulAssign for UnitExponents
Sourcefn mul_assign(&mut self, rhs: Self)
fn mul_assign(&mut self, rhs: Self)
Performs the
*= operation. Read moreSourceimpl PartialEq for UnitExponents
impl PartialEq for UnitExponents
impl Eq for UnitExponents
impl StructuralPartialEq for UnitExponents