Structs
- Unit
- Struct representing a unit of measurement in the SI system via the exponents of
the base units. The unit is purely defined by the values of its fields, meaning
that it can change at runtime. The struct implements basic arithmetic functions
such as multiplication and division (via the
Mul,MulAssign,Div,DivAssigntraits), exponentiation (Unit::powi) and a fallible version of root calculation (Unit::try_nthroot).
Enums
- Predef
Unit - An enum representing predefined
Units.
Traits
- Unit
From Type - A trait to derive
Unitfrom a type. This trait bridges the gap between (external) types representing physical quantities (such as e.g. theQuantitytype from the uom crate) andUnit.